raytraverse.sampler
==========================================================

draw
---------------------------

.. automodule:: raytraverse.sampler.draw
    :members:
    :undoc-members:
    :show-inheritance:

BaseSampler
---------------------------

.. autoclass:: raytraverse.sampler.BaseSampler
    :members:
    :undoc-members:
    :show-inheritance:

Sensor
------
.. autoclass:: raytraverse.sampler.Sensor
    :members:
    :undoc-members:
    :show-inheritance:

ISamplerArea
---------------------------

.. autoclass:: raytraverse.sampler.ISamplerArea
    :members:
    :undoc-members:
    :show-inheritance:

ISamplerSuns
---------------------------

.. autoclass:: raytraverse.sampler.ISamplerSuns
    :members:
    :undoc-members:
    :show-inheritance:

SamplerSuns
---------------------------
.. autoclass:: raytraverse.sampler.SamplerSuns
    :members:
    :undoc-members:
    :show-inheritance:

SamplerArea
---------------------------

.. autoclass:: raytraverse.sampler.SamplerArea
    :members:
    :undoc-members:
    :show-inheritance:


SamplerPt
---------------------------

.. autoclass:: raytraverse.sampler.SamplerPt
    :members:
    :undoc-members:
    :show-inheritance:

SkySamplerPt
--------------------------------

.. autoclass:: raytraverse.sampler.SkySamplerPt
    :members:
    :undoc-members:
    :show-inheritance:

SunSamplerPt
--------------------------------

.. autoclass:: raytraverse.sampler.SunSamplerPt
    :members:
    :undoc-members:
    :show-inheritance:

SunSamplerPtView
------------------------------------

.. autoclass:: raytraverse.sampler.SunSamplerPtView
    :members:
    :undoc-members:
    :show-inheritance:

ImageSampler
--------------------------------

.. autoclass:: raytraverse.sampler.ImageSampler
    :members:
    :undoc-members:
    :show-inheritance:

DeterministicImageSampler
--------------------------------

.. autoclass:: raytraverse.sampler.DeterministicImageSampler
    :members:
    :undoc-members:
    :show-inheritance:
